from typing import Tuple
from PIL.Image import Image
from PIL import Image as Img

def p3d_to_rgb(color: Tuple[float, ...]) -> Tuple[int, ...]:
	"""
	Convert a panda3d color in the form of 3-4 numbers between 0 and 1 to an RGB color in the form
	of 3-4 numbers between 0 and 255.
	"""
	return tuple([round(i*255) for i in color])

def hex_to_rgb(hex: str) -> Tuple[int, ...]:
	"""Covert a hex color string to an RGB color tuple."""
	if hex[0] == "#": hex = hex[1:]
	return tuple(int(hex[i:i+2], 16) for i in range(0, 6, 2))

def rgb_to_p3d(color: Tuple[int, ...]) -> Tuple[float, ...]:
	"""
	Convert an RGB color in the form of 3-4 numbers between 0 and 255 to a panda3d color in the form
	of 3-4 numbers between 0 and 1.
	"""
	return tuple([round(i/255, 3) for i in color])

def rotate_img(img: Image, angle: int) -> Image:
	"""
	Return a rotated copy of an image rotated clockwise by `angle` degrees if `angle` is a multiple
	of 90, else return a copy of the image.
	"""
	if angle == 90:
		return img.transpose(Img.ROTATE_90)
	if angle == 180:
		return img.transpose(Img.ROTATE_180)
	if angle == 270:
		return img.transpose(Img.ROTATE_270)
	return img.copy()